==> haskell-html-conduit-1.3.2.2-290-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-C1s8PELH66B8oXoAxfJ0dm
key:                  html-conduit-1.3.2.2-C1s8PELH66B8oXoAxfJ0dm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  f709f5af26219febcae116315375574f
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-C1s8PELH66B8oXoAxfJ0dm
depends:
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-LEKlJ5sjhOMOY4BoQvHAk
    conduit-extra-1.3.6-2wqo8ucVt5IGPwh2HHGSdk containers-0.6.7
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-H1IDoMUbIU5KkVXM4r4KJI
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.2-296-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-ClxKtqpbEFC5P1cBVXgLwS
key:                  html-conduit-1.3.2.2-ClxKtqpbEFC5P1cBVXgLwS
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  97731934a7fe99b0730b8a599834f162
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-ClxKtqpbEFC5P1cBVXgLwS
depends:
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT
    conduit-extra-1.3.7-IZqbdwWCIVBKlmFf1WuGHS containers-0.6.7
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-HqI64ofa1BLBo89Vn03fsg
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
